<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://ecreations.net/
 * @since      1.0.0
 *
 * @package    Woocommerce_Attributes_Discount
 * @subpackage Woocommerce_Attributes_Discount/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_Attributes_Discount
 * @subpackage Woocommerce_Attributes_Discount/admin
 * @author     ecreations <josel@ecreations.net>
 */
class Woocommerce_Attributes_Discount_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * @param null $post_id
	 *
	 * Save attributes in the coupon
	 */
	public function coupon_data_save($post_id = null){


		if(isset($_POST['custom_global_attribute']) && isset($_POST['global_product_attribute'])){

			update_post_meta( $post_id, 'custom_global_attribute', $_POST['custom_global_attribute'] );
			update_post_meta( $post_id, 'global_product_attribute', $_POST['global_product_attribute'] );
		}else{

			delete_post_meta($post_id, 'custom_global_attribute' );
			delete_post_meta($post_id, 'global_product_attribute');
		}

	}

	/**
	 * Add inputs to the coupon form
	 */
	public function custom_fields()
	{
		global $post;
		$globals =  wc_get_attribute_taxonomies();

		include 'partials/woocommerce-attributes-discount-admin-display.php';

	}

	/**
	 *  Load attributes by ajax request
	 */
	public function globals_attributes_callback(){

		$taxonomy = $_POST['taxonomy'];
		$taxonomy_label = $_POST['taxonomy_label'];

		$args = array(
			'taxonomy' =>	$taxonomy,
			'orderby'    => 'name',
			'hide_empty' => 0,
			'fields' => 'all'
		);
		$all_terms = get_terms(apply_filters( 'woocommerce_product_attribute_terms', $args ));
		$format_terms = array();
		foreach ($all_terms as $term){
			$format_terms[$term->slug] = $term->name;
		}

		$attr_label[] = array('label' => $taxonomy_label,'id'=> $taxonomy, 'values' => $format_terms);
		echo  json_encode($attr_label);

		wp_die();
	}


	public function enqueue_styles() {

		global $post;
		if($post->post_type == 'shop_coupon') {
			
			wp_enqueue_style($this->plugin_name . 'style1', plugin_dir_url(__FILE__) . 'css/woocommerce-attributes-discount-admin.css', array(), $this->version, 'all');
		}
	}

	public function enqueue_scripts() {

		global $post;
		if($post->post_type == 'shop_coupon'){

			wp_enqueue_script( $this->plugin_name. 'script1', plugin_dir_url( __FILE__ ) . 'js/woocommerce-attributes-discount-admin.js', array( 'jquery' ), $this->version, false );
		}




	}
}
