<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ecreations.net/
 * @since      1.0.0
 *
 * @package    Woocommerce_Attributes_Discount
 * @subpackage Woocommerce_Attributes_Discount/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_Attributes_Discount
 * @subpackage Woocommerce_Attributes_Discount/public
 * @author     ecreations <josel@ecreations.net>
 */
class Woocommerce_Attributes_Discount_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * @param $cart_valid
	 * @param $coupon
	 * @return bool
	 *
	 * Check if the coupon es valid for the cart
	 */
	public function coupons_is_valid_cart($cart_valid, $coupon){


		if($cart_valid){

			$globals_attribute_ids = get_post_meta($coupon->id, 'global_product_attribute', true);

			if ( !empty( $globals_attribute_ids )) {

				$globals_attribute_ids = $this->get_global_meta_attr($globals_attribute_ids);




				$cart_valid = false;
				if ( ! WC()->cart->is_empty() ) {


					foreach( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {


						if ($this->matched_coupon($cart_valid,$cart_item['data'],$cart_item,$globals_attribute_ids) )
						{
							$cart_valid = true;
						}
					}
				}
				return $cart_valid;
			}

		}

		return $cart_valid;
	}

	/**
	 * @param $valid
	 * @param $product
	 * @param $coupon
	 * @param $values
	 * @return bool
	 *
	 * Check if the product is valid tio apply the coupon
	 */
	public function coupons_is_valid_product($valid, $product, $coupon, $values){

		if($coupon->is_type( wc_get_product_coupon_types())){

			$globals_attribute_ids = get_post_meta($coupon->id, 'global_product_attribute', true);

			if (  !empty( $globals_attribute_ids ) ) {

				$valid = false;
				$globals_attribute_ids = $this->get_global_meta_attr($globals_attribute_ids);

				if ($this->matched_coupon($valid,$product,$values,$globals_attribute_ids) )
				{
					$valid = true;
				}

				return $valid;
			}

		}

		return $valid;

	}
	/**
	 * Check coupon
	 *
	 * on basket update, check to see if any auto enabled coupons
	 * are valid for adding
	 *
	 * @return  void
	 */
	public function matched_coupon($valid, $product, $values,$globals_attribute_ids){



		$product_attributes = $product->get_attributes();


		if(is_array($product_attributes)) {

			if (is_array($globals_attribute_ids)) {

				$valid  = false;
				foreach ($product_attributes as $tax=>$attribute) {


						$terms = wp_get_post_terms($product->id, $tax, 'all');

						foreach ($terms as $term) {

							if (isset($globals_attribute_ids[$term->taxonomy])){

								if (isset($values['variation']) && $values['variation_id'] &&
									in_array($values['variation']['attribute_' . $term->taxonomy], $globals_attribute_ids[$term->taxonomy])) {
										$valid = true;

								}elseif(isset($values['data']->product_attributes) &&
									in_array($term->slug, $globals_attribute_ids[$term->taxonomy])){
									$valid = true;
								}
							}
						}
 
				}
			}

		}

		return $valid;

	}

	public function get_global_meta_attr($globals_attribute_ids){

		$array_object = array();

		foreach ($globals_attribute_ids as $item){

			$explode = explode('|',$item);

			$array_object[$explode[0]][] = $explode[2];
		}

		return $array_object;

	}

}
